characterchooser: characterchooser

Description Usage Arguments Examples

View source: R/characterchooser.R

Description

This is a function that randomly selects Star Wars characters from the dplyr database and then states that they are the users favorite character.

Usage

1

Arguments

my_fave

Your favorite StarWars character. Default = sampled from dplyr::starwars name column.

Examples

1

MPCA-data/characterchooser documentation built on May 2, 2020, 12:02 a.m.