Description Usage Arguments Examples
View source: R/characterchooser.R
This is a function that randomly selects Star Wars characters from the dplyr database and then states that they are the users favorite character.
1 | characterchooser(my_fave = character)
|
my_fave |
Your favorite StarWars character. Default = sampled from dplyr::starwars name column. |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.